@@ -7,7 +7,9 @@
 #' Density, cumulative density, quantile and simulation of 
 #' the 4-parameter Tukey (1977) \eqn{g}-&-\eqn{h} distributions. 
 #' The quantile-based transformation (Hoaglin 1985) 
-#' and its reverse transformation are also provided.
+#' and its reverse transformation, 
+#' as well as the letter-value based estimates (Hoaglin 1985), 
+#' are also provided.
 #'
 #' @returns
 #' Returned values of individual functions are documented separately.
@@ -22,7 +24,8 @@
 #' John Wiley & Sons, Ltd, New York. 
 #' \doi{10.1002/9781118150702.ch11}
 #'
+#' @author Tingting Zhan
+#'
 #' @keywords internal
-#' @name TukeyGH77-package
-NULL
+'_PACKAGE'
 
